@@ -26,7 +26,6 @@ const _ = Gettext.gettext;
 
 const ExtensionUtils = imports.misc.extensionUtils;
 const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 
 const Config = imports.misc.config;
 
@@ -37,7 +36,7 @@ let Settings;
  */
 function init() {
   ExtensionUtils.initTranslations("Shortcuts");
-  Settings = Convenience.getSettings();
+  Settings = ExtensionUtils.getSettings("org.gnome.shell.extensions.shortcuts");
 }
 
 /**
